@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """sdist tests"""
 
-from __future__ import with_statement
 import locale
 import os
 import shutil
@@ -9,15 +8,13 @@ import sys
 import tempfile
 import unittest
 import unicodedata
-import re
-from setuptools.tests import environment
-
-from setuptools.compat import StringIO, unicode
+import contextlib
 from setuptools.tests.py26compat import skipIf
-from setuptools.command.sdist import sdist, walk_revctrl
+
+from setuptools.compat import StringIO, unicode, PY3, PY2
+from setuptools.command.sdist import sdist
 from setuptools.command.egg_info import manifest_maker
 from setuptools.dist import Distribution
-from setuptools import svn_utils
 
 SETUP_ATTRS = {
     'name': 'sdist_test',
@@ -34,32 +31,33 @@ setup(**%r)
 """ % SETUP_ATTRS
 
 
-if sys.version_info >= (3,):
+if PY3:
     LATIN1_FILENAME = 'smörbröd.py'.encode('latin-1')
 else:
     LATIN1_FILENAME = 'sm\xf6rbr\xf6d.py'
 
 
 # Cannot use context manager because of Python 2.4
+@contextlib.contextmanager
 def quiet():
-    global old_stdout, old_stderr
     old_stdout, old_stderr = sys.stdout, sys.stderr
     sys.stdout, sys.stderr = StringIO(), StringIO()
-
-def unquiet():
-    sys.stdout, sys.stderr = old_stdout, old_stderr
+    try:
+        yield
+    finally:
+        sys.stdout, sys.stderr = old_stdout, old_stderr
 
 
 # Fake byte literals for Python <= 2.5
 def b(s, encoding='utf-8'):
-    if sys.version_info >= (3,):
+    if PY3:
         return s.encode(encoding)
     return s
 
 
 # Convert to POSIX path
 def posix(path):
-    if sys.version_info >= (3,) and not isinstance(path, str):
+    if PY3 and not isinstance(path, str):
         return path.replace(os.sep.encode('ascii'), b('/'))
     else:
         return path.replace(os.sep, '/')
@@ -74,7 +72,7 @@ def decompose(path):
         path = unicodedata.normalize('NFD', path)
         path = path.encode('utf-8')
     except UnicodeError:
-        pass # Not UTF-8
+        pass  # Not UTF-8
     return path
 
 
@@ -85,6 +83,7 @@ class TestSdistTest(unittest.TestCase):
         f = open(os.path.join(self.temp_dir, 'setup.py'), 'w')
         f.write(SETUP_PY)
         f.close()
+
         # Set up the rest of the test package
         test_pkg = os.path.join(self.temp_dir, 'sdist_test')
         os.mkdir(test_pkg)
@@ -112,18 +111,41 @@ class TestSdistTest(unittest.TestCase):
         cmd = sdist(dist)
         cmd.ensure_finalized()
 
-        # squelch output
-        quiet()
-        try:
+        with quiet():
             cmd.run()
-        finally:
-            unquiet()
 
         manifest = cmd.filelist.files
         self.assertTrue(os.path.join('sdist_test', 'a.txt') in manifest)
         self.assertTrue(os.path.join('sdist_test', 'b.txt') in manifest)
         self.assertTrue(os.path.join('sdist_test', 'c.rst') not in manifest)
 
+
+    def test_defaults_case_sensitivity(self):
+        """
+            Make sure default files (README.*, etc.) are added in a case-sensitive
+            way to avoid problems with packages built on Windows.
+        """
+
+        open(os.path.join(self.temp_dir, 'readme.rst'), 'w').close()
+        open(os.path.join(self.temp_dir, 'SETUP.cfg'), 'w').close()
+
+        dist = Distribution(SETUP_ATTRS)
+        # the extension deliberately capitalized for this test
+        # to make sure the actual filename (not capitalized) gets added
+        # to the manifest
+        dist.script_name = 'setup.PY'
+        cmd = sdist(dist)
+        cmd.ensure_finalized()
+
+        with quiet():
+            cmd.run()
+
+        # lowercase all names so we can test in a case-insensitive way to make sure the files are not included
+        manifest = map(lambda x: x.lower(), cmd.filelist.files)
+        self.assertFalse('readme.rst' in manifest, manifest)
+        self.assertFalse('setup.py' in manifest, manifest)
+        self.assertFalse('setup.cfg' in manifest, manifest)
+
     def test_manifest_is_written_with_utf8_encoding(self):
         # Test for #303.
         dist = Distribution(SETUP_ATTRS)
@@ -135,14 +157,14 @@ class TestSdistTest(unittest.TestCase):
         # UTF-8 filename
         filename = os.path.join('sdist_test', 'smörbröd.py')
 
+        # Must create the file or it will get stripped.
+        open(filename, 'w').close()
+
         # Add UTF-8 filename and write manifest
-        quiet()
-        try:
+        with quiet():
             mm.run()
-            mm.filelist.files.append(filename)
+            mm.filelist.append(filename)
             mm.write_manifest()
-        finally:
-            unquiet()
 
         manifest = open(mm.manifest, 'rbU')
         contents = manifest.read()
@@ -156,13 +178,14 @@ class TestSdistTest(unittest.TestCase):
             self.fail(e)
 
         # The manifest should contain the UTF-8 filename
-        if sys.version_info >= (3,):
-            self.assertTrue(posix(filename) in u_contents)
-        else:
-            self.assertTrue(posix(filename) in contents)
+        if PY2:
+            fs_enc = sys.getfilesystemencoding()
+            filename = filename.decode(fs_enc)
+
+        self.assertTrue(posix(filename) in u_contents)
 
     # Python 3 only
-    if sys.version_info >= (3,):
+    if PY3:
 
         def test_write_manifest_allows_utf8_filenames(self):
             # Test for #303.
@@ -175,16 +198,16 @@ class TestSdistTest(unittest.TestCase):
             # UTF-8 filename
             filename = os.path.join(b('sdist_test'), b('smörbröd.py'))
 
+            # Must touch the file or risk removal
+            open(filename, "w").close()
+
             # Add filename and write manifest
-            quiet()
-            try:
+            with quiet():
                 mm.run()
                 u_filename = filename.decode('utf-8')
                 mm.filelist.files.append(u_filename)
                 # Re-write manifest
                 mm.write_manifest()
-            finally:
-                unquiet()
 
             manifest = open(mm.manifest, 'rbU')
             contents = manifest.read()
@@ -204,7 +227,12 @@ class TestSdistTest(unittest.TestCase):
             self.assertTrue(u_filename in mm.filelist.files)
 
         def test_write_manifest_skips_non_utf8_filenames(self):
-            # Test for #303.
+            """
+            Files that cannot be encoded to UTF-8 (specifically, those that
+            weren't originally successfully decoded and have surrogate
+            escapes) should be omitted from the manifest.
+            See https://bitbucket.org/tarek/distribute/issue/303 for history.
+            """
             dist = Distribution(SETUP_ATTRS)
             dist.script_name = 'setup.py'
             mm = manifest_maker(dist)
@@ -215,15 +243,12 @@ class TestSdistTest(unittest.TestCase):
             filename = os.path.join(b('sdist_test'), LATIN1_FILENAME)
 
             # Add filename with surrogates and write manifest
-            quiet()
-            try:
+            with quiet():
                 mm.run()
                 u_filename = filename.decode('utf-8', 'surrogateescape')
-                mm.filelist.files.append(u_filename)
+                mm.filelist.append(u_filename)
                 # Re-write manifest
                 mm.write_manifest()
-            finally:
-                unquiet()
 
             manifest = open(mm.manifest, 'rbU')
             contents = manifest.read()
@@ -250,17 +275,14 @@ class TestSdistTest(unittest.TestCase):
         cmd.ensure_finalized()
 
         # Create manifest
-        quiet()
-        try:
+        with quiet():
             cmd.run()
-        finally:
-            unquiet()
 
         # Add UTF-8 filename to manifest
         filename = os.path.join(b('sdist_test'), b('smörbröd.py'))
         cmd.manifest = os.path.join('sdist_test.egg-info', 'SOURCES.txt')
         manifest = open(cmd.manifest, 'ab')
-        manifest.write(b('\n')+filename)
+        manifest.write(b('\n') + filename)
         manifest.close()
 
         # The file must exist to be included in the filelist
@@ -268,19 +290,16 @@ class TestSdistTest(unittest.TestCase):
 
         # Re-read manifest
         cmd.filelist.files = []
-        quiet()
-        try:
+        with quiet():
             cmd.read_manifest()
-        finally:
-            unquiet()
 
         # The filelist should contain the UTF-8 filename
-        if sys.version_info >= (3,):
+        if PY3:
             filename = filename.decode('utf-8')
         self.assertTrue(filename in cmd.filelist.files)
 
     # Python 3 only
-    if sys.version_info >= (3,):
+    if PY3:
 
         def test_read_manifest_skips_non_utf8_filenames(self):
             # Test for #303.
@@ -290,17 +309,14 @@ class TestSdistTest(unittest.TestCase):
             cmd.ensure_finalized()
 
             # Create manifest
-            quiet()
-            try:
+            with quiet():
                 cmd.run()
-            finally:
-                unquiet()
 
             # Add Latin-1 filename to manifest
             filename = os.path.join(b('sdist_test'), LATIN1_FILENAME)
             cmd.manifest = os.path.join('sdist_test.egg-info', 'SOURCES.txt')
             manifest = open(cmd.manifest, 'ab')
-            manifest.write(b('\n')+filename)
+            manifest.write(b('\n') + filename)
             manifest.close()
 
             # The file must exist to be included in the filelist
@@ -308,21 +324,18 @@ class TestSdistTest(unittest.TestCase):
 
             # Re-read manifest
             cmd.filelist.files = []
-            quiet()
-            try:
+            with quiet():
                 try:
                     cmd.read_manifest()
                 except UnicodeDecodeError:
                     e = sys.exc_info()[1]
                     self.fail(e)
-            finally:
-                unquiet()
 
             # The Latin-1 filename should have been skipped
             filename = filename.decode('latin-1')
             self.assertFalse(filename in cmd.filelist.files)
 
-    @skipIf(sys.version_info >= (3,) and locale.getpreferredencoding() != 'UTF-8',
+    @skipIf(PY3 and locale.getpreferredencoding() != 'UTF-8',
             'Unittest fails if locale is not utf-8 but the manifests is recorded correctly')
     def test_sdist_with_utf8_encoded_filename(self):
         # Test for #303.
@@ -335,16 +348,13 @@ class TestSdistTest(unittest.TestCase):
         filename = os.path.join(b('sdist_test'), b('smörbröd.py'))
         open(filename, 'w').close()
 
-        quiet()
-        try:
+        with quiet():
             cmd.run()
-        finally:
-            unquiet()
 
         if sys.platform == 'darwin':
             filename = decompose(filename)
 
-        if sys.version_info >= (3,):
+        if PY3:
             fs_enc = sys.getfilesystemencoding()
 
             if sys.platform == 'win32':
@@ -373,14 +383,11 @@ class TestSdistTest(unittest.TestCase):
         open(filename, 'w').close()
         self.assertTrue(os.path.isfile(filename))
 
-        quiet()
-        try:
+        with quiet():
             cmd.run()
-        finally:
-            unquiet()
 
-        if sys.version_info >= (3,):
-            #not all windows systems have a default FS encoding of cp1252
+        if PY3:
+            # not all windows systems have a default FS encoding of cp1252
             if sys.platform == 'win32':
                 # Latin-1 is similar to Windows-1252 however
                 # on mbcs filesys it is not in latin-1 encoding
@@ -396,144 +403,18 @@ class TestSdistTest(unittest.TestCase):
                 filename = filename.decode('latin-1')
                 self.assertFalse(filename in cmd.filelist.files)
         else:
-            # No conversion takes place under Python 2 and the file
-            # is included. We shall keep it that way for BBB.
-            self.assertTrue(filename in cmd.filelist.files)
-
-
-def soruce_test(self):
-    code, data = svn_utils._run_command([sys.executable, "setup.py", "egg_info"], stream=1)
-        
-    if code:
-        raise AssertionError(data)
-
-    sources = os.path.join('dummy.egg-info', 'SOURCES.txt')
-    contents = """CHANGES.txt
-CONTRIBUTORS.txt
-HISTORY.txt
-LICENSE
-MANIFEST.in
-README.txt
-setup.py
-dummy/__init__.py
-dummy/test.txt
-dummy.egg-info/PKG-INFO
-dummy.egg-info/SOURCES.txt
-dummy.egg-info/dependency_links.txt
-dummy.egg-info/top_level.txt"""
-
-    with open(sources, 'r') as infile:
-        read_contents = infile.read()
-
-    self.assertEqual(contents, read_contents)
-
-
-class TestSvnDummy(environment.ZippedEnvironment):
-
-    def setUp(self):
-        version = svn_utils.SvnInfo.get_svn_version()
-        self.base_version = tuple([int(x) for x in version.split('.')][:2])
-
-        if not self.base_version:
-            raise ValueError('No SVN tools installed')
-        elif self.base_version < (1,3):
-            raise ValueError('Insufficient SVN Version %s' % version)
-        elif self.base_version >= (1,9):
-            #trying the latest version
-            self.base_version = (1,8)
-
-        self.dataname = "dummy%i%i" % self.base_version
-        self.datafile = os.path.join('setuptools', 'tests',
-                                     'svn_data', self.dataname + ".zip")
-        super(TestSvnDummy, self).setUp()
-            
-    def test_sources(self):
-        soruce_test(self)
-
-
-class TestSvnDummyLegacy(environment.ZippedEnvironment):
-
-    def setUp(self):
-        self.base_version = (1,6)
-        self.path_variable = None
-        for env in os.environ:
-            if env.lower() == 'path':
-                self.path_variable = env
-        self.old_path = os.environ[self.path_variable]
-        os.environ[self.path_variable] = ''
-
-        if self.path_variable is None:
-            self.skipTest('Cannot figure out how to modify path')
-
-        self.dataname = "dummy%i%i" % self.base_version
-        self.datafile = os.path.join('setuptools', 'tests',
-                                     'svn_data', self.dataname + ".zip")
-        super(TestSvnDummyLegacy, self).setUp()
-
-    def tearDown(self):
-        os.environ[self.path_variable] = self.old_path
-        super(TestSvnDummyLegacy, self).tearDown()
-
-    def test_sources(self):
-        soruce_test(self)
-
-
-class TestSvn(environment.ZippedEnvironment):
-
-    def setUp(self):
-        version = svn_utils.SvnInfo.get_svn_version()
-        self.base_version = tuple([int(x) for x in version.split('.')][:2])
-
-        if not self.base_version:
-            raise ValueError('No SVN tools installed')
-        elif self.base_version < (1,3):
-            raise ValueError('Insufficient SVN Version %s' % version)
-        elif self.base_version >= (1,9):
-            #trying the latest version
-            self.base_version = (1,8)
-
-        self.dataname = "svn%i%i_example" % self.base_version
-        self.datafile = os.path.join('setuptools', 'tests',
-                                     'svn_data', self.dataname + ".zip")
-        super(TestSvn, self).setUp()
-
-    def test_walksvn(self):
-        if self.base_version >= (1,6):
-            folder2 = 'third party2'
-            folder3 = 'third party3'
-        else:
-            folder2 = 'third_party2'
-            folder3 = 'third_party3'
-
-        #TODO is this right
-        expected = set([
-            os.path.join('a file'),
-            os.path.join(folder2, 'Changes.txt'),
-            os.path.join(folder2, 'MD5SUMS'),
-            os.path.join(folder2, 'README.txt'),
-            os.path.join(folder3, 'Changes.txt'),
-            os.path.join(folder3, 'MD5SUMS'),
-            os.path.join(folder3, 'README.txt'),
-            os.path.join(folder3, 'TODO.txt'),
-            os.path.join(folder3, 'fin'),
-            os.path.join('third_party', 'README.txt'),
-            os.path.join('folder', folder2, 'Changes.txt'),
-            os.path.join('folder', folder2, 'MD5SUMS'),
-            os.path.join('folder', folder2, 'WatashiNiYomimasu.txt'),
-            os.path.join( 'folder', folder3, 'Changes.txt'),
-            os.path.join('folder', folder3, 'fin'),
-            os.path.join('folder', folder3, 'MD5SUMS'),
-            os.path.join('folder', folder3, 'oops'),
-            os.path.join('folder', folder3, 'WatashiNiYomimasu.txt'),
-            os.path.join('folder', folder3, 'ZuMachen.txt'),
-            os.path.join('folder', 'third_party', 'WatashiNiYomimasu.txt'),
-            os.path.join('folder', 'lalala.txt'),
-            os.path.join('folder', 'quest.txt'),
-            #The example will have a deleted file (or should) but shouldn't return it
-            ])
-        self.assertEqual(set(x for x in walk_revctrl()), expected)
+            # Under Python 2 there seems to be no decoded string in the
+            # filelist.  However, due to decode and encoding of the
+            # file name to get utf-8 Manifest the latin1 maybe excluded
+            try:
+                # fs_enc should match how one is expect the decoding to
+                # be proformed for the manifest output.
+                fs_enc = sys.getfilesystemencoding()
+                filename.decode(fs_enc)
+                self.assertTrue(filename in cmd.filelist.files)
+            except UnicodeDecodeError:
+                self.assertFalse(filename in cmd.filelist.files)
 
 
 def test_suite():
     return unittest.defaultTestLoader.loadTestsFromName(__name__)
-
